@@ -5,7 +5,7 @@ use JSON qw/decode_json to_json/;
 use Sub::Data::Recursive;
 use Getopt::Long qw/GetOptionsFromArray/;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 my $MAX_DEPTH = 10;
 
@@ -125,11 +125,30 @@ App::jl is recursive JSON decoder. This module can decode JSON in JSON.
 See L<jl> for CLI to view logs.
 
 
+=head1 METHODS
+
+=head2 new
+
+constructor
+
+=head2 opt
+
+getter of optional values
+
+=head2 run
+
+The main routine
+
+=head2 process
+
+The parser of the line
+
+
 =head1 REPOSITORY
 
 =begin html
 
-<a href="http://travis-ci.org/bayashi/App-jl"><img src="https://secure.travis-ci.org/bayashi/App-jl.png"/></a> <a href="https://coveralls.io/r/bayashi/App-jl"><img src="https://coveralls.io/repos/bayashi/App-jl/badge.png?branch=master"/></a>
+<a href="http://travis-ci.org/bayashi/App-jl"><img src="https://secure.travis-ci.org/bayashi/App-jl.png?_t=1557028055"/></a> <a href="https://coveralls.io/r/bayashi/App-jl"><img src="https://coveralls.io/repos/bayashi/App-jl/badge.png?_t=1557028055&branch=master"/></a>
 
 =end html
 
